@@ -1,5 +1,7 @@
 """Format adapter for sql."""
 
+from __future__ import annotations
+
 from typing import Generator, Union
 
 from cli_helpers.tabular_output import TabularOutputFormatter
@@ -30,18 +32,18 @@ def adapter(data: list[str], headers: list[str], table_format: Union[str, None]
     if len(tables) > 0:
         table = tables[0]
         if table[0]:
-            table_name = "{}.{}".format(*table[:2])
+            table_name = f'{table[0]}.{table[1]}'
         else:
             table_name = table[1]
     else:
         table_name = "`DUAL`"
     if table_format == "sql-insert":
         h = "`, `".join(headers)
-        yield "INSERT INTO {} (`{}`) VALUES".format(table_name, h)
+        yield f'INSERT INTO {table_name} (`{h}`) VALUES'
         prefix = "  "
         for d in data:
             values = ", ".join(escape_for_sql_statement(v) for i, v in enumerate(d))
-            yield "{}({})".format(prefix, values)
+            yield f'{prefix}({values})'
             if prefix == "  ":
                 prefix = ", "
         yield ";"
@@ -51,15 +53,15 @@ def adapter(data: list[str], headers: list[str], table_format: Union[str, None]
         if len(s) > 2:
             keys = int(s[-1])
         for d in data:
-            yield "UPDATE {} SET".format(table_name)
+            yield f'UPDATE {table_name} SET'
             prefix = "  "
             for i, v in enumerate(d[keys:], keys):
-                yield "{}`{}` = {}".format(prefix, headers[i], escape_for_sql_statement(v))
+                yield f'{prefix}`{headers[i]}` = {escape_for_sql_statement(v)}'
                 if prefix == "  ":
                     prefix = ", "
             f = "`{}` = {}"
             where = (f.format(headers[i], escape_for_sql_statement(d[i])) for i in range(keys))
-            yield "WHERE {};".format(" AND ".join(where))
+            yield f'WHERE {" AND ".join(where)};'
 
 
 def register_new_formatter(tof: TabularOutputFormatter):
